Coverage for cc_modules/tests/cc_device_tests.py: 36%

1"""

2 camcops_server/cc_modules/tests/cc_device_tests.py

3

4===============================================================================

5

6 Copyright (C) 2012, University of Cambridge, Department of Psychiatry.

7 Created by Rudolf Cardinal (rnc1001@cam.ac.uk).

8

9 This file is part of CamCOPS.

10

11 CamCOPS is free software: you can redistribute it and/or modify

12 it under the terms of the GNU General Public License as published by

13 the Free Software Foundation, either version 3 of the License, or

14 (at your option) any later version.

15

16 CamCOPS is distributed in the hope that it will be useful,

17 but WITHOUT ANY WARRANTY; without even the implied warranty of

18 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the

19 GNU General Public License for more details.

20

21 You should have received a copy of the GNU General Public License

22 along with CamCOPS. If not, see <https://www.gnu.org/licenses/>.

23

24===============================================================================

25

26"""

27

28 from camcops_server.cc_modules.cc_device import Device

29 from camcops_server.cc_modules.cc_unittest import DemoDatabaseTestCase

30

31

32# =============================================================================

33# Unit tests

34# =============================================================================

35

36

37 class DeviceTests(DemoDatabaseTestCase):

38 """

39 Unit tests.

40 """

41

42 def test_device(self) -> None:

43 self.announce("test_device")

44 q = self.dbsession.query(Device)

45 d = q.first() # type: Device

46 assert d, "Missing Device in demo database!"

47 self.assertIsInstance(d.get_friendly_name(), str)

48 self.assertIsInstance(d.get_id(), int)

49 self.assertIsInstance(d.is_valid(), bool)